@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+"""
+Init autodocker module
+"""
 from os import path, listdir
 from typing import Iterable, Type
 
@@ -24,10 +27,13 @@ _config = {
 
 
 def all_project_types() -> list[str]:
-    return [i for i in _config.keys()]
+    """
+    Returns all project types
+    """
+    return list(_config)
 
 
-def generate(
+def generate(  # pylint: disable=too-many-arguments
         project_path: str,
         config: dict[str, Type[ABCFileType]] = None,
         ignore_list: list[str] = None,
@@ -35,6 +41,15 @@ def generate(
         extend: list[str] = None,
         output: str = 'docs'
 ) -> Iterable[tuple[int, int]]:
+    """Runs filetypes
+
+    :param project_path: path to the project
+    :param config: config dictionary
+    :param ignore_list: list of file extensions that need to ignore
+    :param document_type: project document type
+    :param extend: list of file extensions that need to include
+    :param output: output directory
+    """
     if config is None:
         config = _config
     if document_type not in config:
@@ -55,12 +70,12 @@ def _iter_dir(directory: str) -> Iterable[str]:
     """
     res = listdir(directory)
     for i in res:
-        p = path.join(directory, i)
-        if path.isdir(p):
-            for j in _iter_dir(p):
+        full_path = path.join(directory, i)
+        if path.isdir(full_path):
+            for j in _iter_dir(full_path):
                 yield j
         else:
-            yield p
+            yield full_path
 
 
 def _process(
@@ -83,16 +98,16 @@ def _process(
     file_extensions = (
         [i for i in file_types.keys() if i not in ignore_files]
         if ignore_files else
-        [i for i in file_types.keys()]
+        list(file_types)
     )
     if path.isdir(project_path):
         files = [i for i in _iter_dir(project_path) if path.splitext(i)[1] in file_extensions]
         length = len(files)
-        for i, v in enumerate(files):
-            file, ext = path.splitext(v)
-            file_types[ext].process(f'{path.join(project_path, v)}', output_dir)
+        for i, filename in enumerate(files):
+            _, ext = path.splitext(filename)
+            file_types[ext].process(f'{path.join(project_path, filename)}', output_dir)
             yield i, length
     else:
-        file, ext = path.splitext(project_path)
+        _, ext = path.splitext(project_path)
         file_types[ext].process(project_path, output_dir, True)
         yield 1, 1
