@@ -8,17 +8,26 @@ from glob import glob
 from pprint import pprint
 
 import click
+import uvicorn
 
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 from fastapi.responses import HTMLResponse
 from fastapi import status
-from uvicorn.server import Server, Config
 from jinja2 import FileSystemLoader, Environment, select_autoescape
 
-from hapdoc.autodocker import generate, all_project_types
-from hapdoc.autodocker.filetypes import Py, FastApi
-from hapdoc.md import Md2Html
+from .autodocker import generate, all_project_types
+from .md import Md2Html
+
+
+app = FastAPI(docs_url=None, redoc_url=None)
+app.add_middleware(
+    CORSMiddleware,
+    allow_origins=['*'],
+    allow_methods=['*'],
+    allow_headers=['*'],
+    allow_credentials=True
+)
 
 
 @click.group()
@@ -93,6 +102,7 @@ def gen(
 
 
 @hapdoc.command()
+@click.argument('docs', type=str)
 @click.option(
     '-h', '--host', 'host',
     default='127.0.0.1',
@@ -103,11 +113,6 @@ def gen(
     default='5000',
     type=str
 )
-@click.option(
-    '-d', '--docs', 'docs',
-    default='docs',
-    type=str
-)
 @click.option(
     '-t', '--template', 'templates_folder',
     default='hapdoc/templates/vitepress',
@@ -133,7 +138,7 @@ def gen(
     default='#343434',
     type=str
 )
-def serve(
+def serve(  # pylint: disable=too-many-arguments
         host: str,
         port: str,
         docs: str,
@@ -155,14 +160,7 @@ def serve(
     :param background_color: docs background color
     :param surface_color: docs surface color
     """
-    app = FastAPI(docs_url=None, redoc_url=None)
-    app.add_middleware(
-        CORSMiddleware,
-        allow_origins=['*'],
-        allow_methods=['*'],
-        allow_headers=['*'],
-        allow_credentials=True
-    )
+
     env = Environment(
         loader=FileSystemLoader(templates_folder),
         autoescape=select_autoescape()
@@ -172,7 +170,6 @@ def serve(
         f.replace(path.normpath(docs), '')
         for f in glob(path.normpath(docs + '/**/*.md'), recursive=True)
     ]
-    print(md_files)
 
     sidebar = {}
 
@@ -180,14 +177,11 @@ def serve(
         mdf = mdf.strip('\\').strip('/')
         directory = [i for i in mdf.split(os.sep) if i]
         mdf = mdf.replace('\\', '/')
-        print(directory)
         temp_sidebar: dict = sidebar
         for idx, temp_path in enumerate(directory):
             # File
-            print(idx, temp_path, len(directory))
-            if idx == len(directory)-1:
+            if idx == len(directory) - 1:
                 file = temp_path.rsplit('.', 1)[0]
-                print(temp_sidebar)
                 temp_sidebar[file] = {
                     '_data': {
                         'id': mdf.replace('\\', '_'),
@@ -221,7 +215,6 @@ def serve(
         if path.exists(full_path) and path.isfile(full_path):
             with open(full_path, 'r', encoding='utf-8') as filename:
                 data = filename.read()
-            full_path = full_path.replace('\\', '/').rstrip('/')
             return HTMLResponse(
                 template.render(
                     pageData=Md2Html.cast(data),
@@ -241,16 +234,5 @@ def serve(
             status_code=status.HTTP_404_NOT_FOUND
         )
 
-    server = Server(
-        config=Config(
-            app,
-            host=host,
-            port=port
-        )
-    )
     click.echo(f'Your server runs at http://{host}:{port}')
-    server.run()
-
-
-if __name__ == '__main__':
-    hapdoc()
+    uvicorn.run(app, host=host, port=int(port))
